@@ -25,6 +25,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 
@@ -60,6 +62,10 @@ class Alarms:
                 upper_alarm_interval_index=123
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Alarms.__init__)
+            check_type(argname="argument lower_alarm_interval_index", value=lower_alarm_interval_index, expected_type=type_hints["lower_alarm_interval_index"])
+            check_type(argname="argument upper_alarm_interval_index", value=upper_alarm_interval_index, expected_type=type_hints["upper_alarm_interval_index"])
         self._values: typing.Dict[str, typing.Any] = {}
         if lower_alarm_interval_index is not None:
             self._values["lower_alarm_interval_index"] = lower_alarm_interval_index
@@ -98,7 +104,7 @@ class ArbitraryIntervals:
         self,
         *,
         absolute: builtins.bool,
-        intervals: typing.Sequence["ScalingInterval"],
+        intervals: typing.Sequence[typing.Union["ScalingInterval", typing.Dict[str, typing.Any]]],
     ) -> None:
         '''
         :param absolute: 
@@ -123,6 +129,10 @@ class ArbitraryIntervals:
                 )]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ArbitraryIntervals.__init__)
+            check_type(argname="argument absolute", value=absolute, expected_type=type_hints["absolute"])
+            check_type(argname="argument intervals", value=intervals, expected_type=type_hints["intervals"])
         self._values: typing.Dict[str, typing.Any] = {
             "absolute": absolute,
             "intervals": intervals,
@@ -186,6 +196,11 @@ class CompleteScalingInterval:
                 change=123
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CompleteScalingInterval.__init__)
+            check_type(argname="argument lower", value=lower, expected_type=type_hints["lower"])
+            check_type(argname="argument upper", value=upper, expected_type=type_hints["upper"])
+            check_type(argname="argument change", value=change, expected_type=type_hints["change"])
         self._values: typing.Dict[str, typing.Any] = {
             "lower": lower,
             "upper": upper,
@@ -250,6 +265,10 @@ class _IRandomGeneratorProxy:
         :param min: -
         :param max: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IRandomGenerator.next_int)
+            check_type(argname="argument min", value=min, expected_type=type_hints["min"])
+            check_type(argname="argument max", value=max, expected_type=type_hints["max"])
         return typing.cast(jsii.Number, jsii.invoke(self, "nextInt", [min, max]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -291,6 +310,11 @@ class ScalingInterval:
                 upper=123
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ScalingInterval.__init__)
+            check_type(argname="argument change", value=change, expected_type=type_hints["change"])
+            check_type(argname="argument lower", value=lower, expected_type=type_hints["lower"])
+            check_type(argname="argument upper", value=upper, expected_type=type_hints["upper"])
         self._values: typing.Dict[str, typing.Any] = {
             "change": change,
         }
